/**
 * Класс для работы с токенами.
 */
class TokenHelper {
    /**
     * Установка токенов.
     *
     * @param {string} access_token
     * @param {int} expires_in
     * @param token_type
     * @param {string} refresh_token
     */
    setToken(access_token, expires_in, token_type = 'Bearer', refresh_token = undefined) {

        if (access_token === undefined || access_token.length < 1) {
            console.warn(`Внимание! Не удалось установить токен: ${access_token}, т.к. он не задан или пуст!`);
            return false;
        }

        localStorage.setItem('access_token', access_token);

        localStorage.setItem('token_type', token_type);

        if (expires_in !== undefined) {
            localStorage.setItem('expires_in', expires_in + new Date());
        }

        if (refresh_token !== undefined) {
            localStorage.setItem('refresh_token', refresh_token);
        }

        return true;
    }

    /**
     * Проверить авторизованность (наличие установленного токена и время его жизни).
     */
    isAuthenticated() {
        !TokenHelper.tokenWasExpired() && this.getToken()
    }

    /**
     * Получить токен доступа.
     */
    getToken() {
        localStorage.getItem('access_token')
    }

    /**
     * Проверить, истекло ли время жизни токена.
     */
    static tokenWasExpired() {
        const expires_in = localStorage.getItem('expires_in');

        return !expires_in ? false : new Date() >= expires_in;
    }

    /**
     * Удалить токены из хранилища.
     */
    static removeTokens() {
        localStorage.removeItem('access_token');
        localStorage.removeItem('expires_in');
        localStorage.removeItem('refresh_token');
        localStorage.removeItem('token_type');
    }
}

export default TokenHelper;